//=============================================================================
// NoAnimMeshGun.
//=============================================================================
class NoAnimMeshGun expands RenderGun;

var byte AnimNum;
var float AnimmRate,AnimPos;
var rotator UseRot;
var vector UsePos;
struct EfAttachment
{
	var Effects EfActor;
	var vector EfOffset;
};
var EfAttachment AttachedEffects[26];
var byte NumAttachments;

simulated function AnimEnd()
{
	UsePos = vect(0,0,0);
	UseRot = rot(0,0,0);
	Super.AnimEnd();
}
simulated function SetActionAnim( name AnimName, float AnimSpeed )
{
	AnimPos = 0;
	AnimmRate = AnimSpeed;
	UsePos = vect(0,0,0);
	UseRot = rot(0,0,0);
	if( AnimName=='Select' )
	{
		AnimNum = 1;
		UsePos.Z = -550;
		UsePos.X = -100;
		UseRot.Pitch = 13240;
	}
	if( AnimName=='Down' )
		AnimNum = 2;
	if( AnimName=='Fire' )
		AnimNum = 3;
}
simulated function ModifyViewOffset( out vector AddedPos, out rotator AddedRot )
{
	if( AnimNum==0 ) Return;
	AddedPos = UsePos;
	AddedRot = UseRot;
}
simulated function Tick( float Delta )
{
	if( Level.NetMode==NM_Client )
	{
		if( !OwnerG.bNetOwner )
		{
			if( BeginScanTime<0.5 )
			{
				BeginScanTime+=Delta;
				OldFlashCount = OwnerG.FlashCount;
			}
			if( OldFlashCount!=OwnerG.FlashCount )
			{
				OldFlashCount = OwnerG.FlashCount;
				OwnerG.SpawnEffect(OwnerG.ReplicatedFX,OwnerG.ReplicatedFXRot,OwnerG.GetFireStart());
			}
		}
		if( Instigator!=None && Instigator.Weapon==OwnerG )
		{
			if( bDidFire )
			{
				if( Instigator.bFire==0 && Instigator.bAltFire==0 )
					bDidFire = False;
				Return;
			}
			if( Instigator.bFire!=0 )
			{
				bDidFire = True;
				OwnerG.Fire(0);
			}
			else if( Instigator.bAltFire!=0 )
			{
				bDidFire = True;
				OwnerG.AltFire(0);
			}
		}
	}
	if( Level.NetMode==NM_DedicatedServer )
		Disable('Tick');
	if( !OwnerG.IsLocallyControlled() )
		Return;
	if( AnimNum!=0 )
		TickAnimation(Delta*AnimmRate);
}
simulated function TickAnimation( float D )
{
	local float F;
	
	AnimPos+=D;
	if( AnimNum==1 )
	{
		if( UsePos.X<0 )
			UsePos.X-=(UsePos.X-30)*D*10;
		if( UsePos.Z>-250 && UseRot.Pitch>0 )
			UseRot.Pitch-=(UseRot.Pitch+500)*D*12;
		else if( UseRot.Pitch<0 )
			UseRot.Pitch = 0;
		if( UsePos.Z<0 )
			UsePos.Z-=(UsePos.Z-20)*D*10;
		else
		{
			AnimNum = 0;
			AnimEnd();
		}
	}
	else if( AnimNum==2 )
	{
		if( UsePos.X>-200 )
			UsePos.X-=Abs(UsePos.X-30)*D*10;
		UseRot.Pitch-=abs(UseRot.Pitch-100)*6*D;
		if( UsePos.Z>-700 )
			UsePos.Z-=Abs(UsePos.Z-20)*D*10;
		else AnimNum = 0;
	}
	else
	{
		if( AnimPos<0.5 )
		{
			F = AnimPos/0.5;
			F*=F;
			UsePos.X = F*-200;
			UsePos.Z = F*100;
			UseRot.Pitch = F*2000;
		}
		else
		{
			F = AnimPos-0.5;
			F/=1.5;
			F = 1-F;
			F*=F;
			if( F>1 )
				F = 1;
			UsePos.X = F*-200;
			UsePos.Z = F*100;
			UseRot.Pitch = F*2000;
			if( AnimPos>2 )
			{
				AnimNum = 0;
				AnimEnd();
			}
		}
	}
}
simulated function bool AttachEffectTo( Effects Ef, vector Offset )
{
	if( NumAttachments==26 )
		Return False;
	AttachedEffects[NumAttachments].EfActor = Ef;
	AttachedEffects[NumAttachments].EfOffset = Offset;
	NumAttachments++;
	Ef.bHidden = True; // Hide actor from third person view.
	Ef.RemoteRole = ROLE_None;
	Return True;
}
simulated function Destroyed()
{
	local int i;
	
	For( i=0; i<NumAttachments; i++ )
	{
		if( AttachedEffects[i].EfActor!=None )
			AttachedEffects[i].EfActor.Destroy();
	}
	Super.Destroyed();
}
simulated function DeAttachEffect( Effects Ef )
{
	local int i;
	
	if( Ef==None || NumAttachments==0 ) Return;
	For( i=0; i<NumAttachments; i++ )
	{
		if( AttachedEffects[i].EfActor==Ef )
		{
			if( i==(NumAttachments-1) )
			{
				NumAttachments--;
				Return;
			}
			AttachedEffects[i] = AttachedEffects[NumAttachments-1];
			NumAttachments--;
			Return;
		}
	}
}
simulated event RenderOverlays( canvas Canvas )
{
	local vector X,Y,Z;
	local int i;
	
	Super.RenderOverlays(Canvas);
	if( NumAttachments==0 )
		Return;
	GetAxes(Rotation,X,Y,Z);
	For( i=0; i<NumAttachments; i++ )
	{
		if( AttachedEffects[i].EfActor!=None )
		{
			AttachedEffects[i].EfActor.SetLocation(Location+X*AttachedEffects[i].EfOffset.X+Y*AttachedEffects[i].EfOffset.Y+Z*AttachedEffects[i].EfOffset.Z);
			Canvas.DrawActor(AttachedEffects[i].EfActor,False);
		}
	}
}

defaultproperties
{
}
